package geniusweb.domaineditor.model;

import geniusweb.issuevalue.ValueSet;
import tudelft.utilities.mvc.model.BasicModel;
import tudelft.utilities.mvc.model.ListModel;
import tudelft.utilities.mvc.model.Model;

/**
 * Contains a {@link ValueSet}. See the DiscreteValueSetModel- and
 * {@link NumberValueSetModel}
 *
 */
public interface ValueSetModel extends Model {
	/**
	 * 
	 * @return first value in the model
	 */
	BasicModel first();

	/**
	 * 
	 * @return {@link ListModel} with the available values. This ListModel may
	 *         not support edit actions.
	 */
	public ListModel<? extends BasicModel> getList();

	/**
	 * 
	 * @return the currently contained value in the model. We do NOT specify the
	 *         type of the returned object because it would have to be a type
	 *         parameter added to Model, which leads to all kinds of issues with
	 *         excessive parameterization and issues when a class extends eg a
	 *         MapModel. NOTE: also derived classes like ListModel should not
	 *         specify that they return {@link List} or so: further subclassing
	 *         of eg a ListModel might be eg a ValueSet which would not return a
	 *         List again.
	 * @throws IllegalStateException if the model is not correctly filled in at
	 *                               this moment.
	 */
	public ValueSet getCurrentValue() throws IllegalStateException;

	/**
	 * Sets the current value based on the proviced obj
	 * 
	 * @param obj the object to load the model with. Mirror of
	 *            {@link #getCurrentValue()} and the Object is the same type.
	 * @throws IllegalArgumentException if the object is not the expected object
	 *                                  type
	 */
	public void setCurrentValue(ValueSet obj) throws IllegalArgumentException;

}
